@@ -301,10 +301,12 @@ proxy_get_permissions_from_dialog (EAccount *account)
 }
 
 static gint
-proxy_dialog_store_widgets_data (EAccount *account, gint32 dialog, GtkWindow *parent)
+proxy_dialog_store_widgets_data (EAccount *account,
+                                 gint32 dialog,
+                                 GtkWindow *parent)
 {
 	GtkTreeIter iter;
-	GtkTreeSelection* account_select;
+	GtkTreeSelection * account_select;
 	GtkTreeModel *model;
 	proxyHandler *new_proxy = NULL;
 	proxyDialogPrivate *priv;
@@ -359,7 +361,7 @@ proxy_dialog_store_widgets_data (EAccount *account, gint32 dialog, GtkWindow *pa
 					/*check whether already exists*/
 					existing_list = priv->proxy_list;
 
-					for (;existing_list; existing_list = g_list_next (existing_list)) {
+					for (; existing_list; existing_list = g_list_next (existing_list)) {
 						new_proxy = (proxyHandler *) existing_list->data;
 						if (!g_ascii_strcasecmp (new_proxy->proxy_email, email)) {
 							if (new_proxy->flags & E_GW_PROXY_DELETED) {
@@ -461,7 +463,8 @@ proxy_dialog_initialize_widgets (EAccount *account)
 }
 
 static EGwConnection *
-proxy_get_cnc (EAccount *account, GtkWindow *parent_window)
+proxy_get_cnc (EAccount *account,
+               GtkWindow *parent_window)
 {
 	CamelSettings *settings;
 	EGwConnection *cnc;
@@ -510,7 +513,7 @@ proxy_get_cnc (EAccount *account, GtkWindow *parent_window)
 	password = e_passwords_get_password (NULL, key);
 	if (!password)
 		password = e_passwords_ask_password (prompt, NULL, key, prompt,
-				E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET, &remember, parent_window);
+				E_PASSWORDS_REMEMBER_FOREVER | E_PASSWORDS_SECRET, &remember, parent_window);
 	g_free (prompt);
 
 	cnc = e_gw_connection_new (uri, url->user, password);
@@ -521,7 +524,8 @@ proxy_get_cnc (EAccount *account, GtkWindow *parent_window)
 }
 
 void
-proxy_abort (GtkWidget *button, EConfigHookItemFactoryData *data)
+proxy_abort (GtkWidget *button,
+             EConfigHookItemFactoryData *data)
 {
 	EMConfigTargetAccount *target_account;
 	EAccount *account;
@@ -539,7 +543,8 @@ proxy_abort (GtkWidget *button, EConfigHookItemFactoryData *data)
 }
 
 void
-proxy_commit (GtkWidget *button, EConfigHookItemFactoryData *data)
+proxy_commit (GtkWidget *button,
+              EConfigHookItemFactoryData *data)
 {
 	EAccount *account;
 	EMConfigTargetAccount *target_account;
@@ -558,13 +563,13 @@ proxy_commit (GtkWidget *button, EConfigHookItemFactoryData *data)
 
 	priv = prd->priv;
 	list_iter = priv->proxy_list;
-	for (;list_iter; list_iter = g_list_next (list_iter)) {
+	for (; list_iter; list_iter = g_list_next (list_iter)) {
 		aclInstance = (proxyHandler *) list_iter->data;
 
 		/* Handle case where the structure is new and deleted*/
 		if ( !((aclInstance->flags & E_GW_PROXY_NEW) && (aclInstance->flags & E_GW_PROXY_DELETED))) {
 
-			if ( !E_IS_GW_CONNECTION (prd->cnc))	/* Add check in case the connection request fails*/
+			if ( !E_IS_GW_CONNECTION (prd->cnc))	/* Add check in case the connection request fails */
 				prd->cnc = proxy_get_cnc (account, GTK_WINDOW (gtk_widget_get_toplevel (button)));
 
 			if (aclInstance->flags & E_GW_PROXY_NEW )
@@ -626,7 +631,7 @@ proxy_update_tree_view (EAccount *account)
 	gtk_tree_store_clear (priv->store);
 	list_iter = priv->proxy_list;
 
-	for (;list_iter; list_iter = g_list_next (list_iter)) {
+	for (; list_iter; list_iter = g_list_next (list_iter)) {
 		aclInstance = (proxyHandler *) list_iter->data;
 
 		if (!(aclInstance->flags & E_GW_PROXY_DELETED )) {
@@ -643,8 +648,9 @@ proxy_update_tree_view (EAccount *account)
 	gtk_tree_view_set_model (GTK_TREE_VIEW (priv->tree), GTK_TREE_MODEL (priv->store));
 }
 
-GtkWidget*
-org_gnome_proxy (EPlugin *epl, EConfigHookItemFactoryData *data)
+GtkWidget *
+org_gnome_proxy (EPlugin *epl,
+                 EConfigHookItemFactoryData *data)
 {
 	EMConfigTargetAccount *target_account;
 	EShell *shell;
@@ -735,7 +741,10 @@ org_gnome_proxy (EPlugin *epl, EConfigHookItemFactoryData *data)
 }
 
 static gboolean
-proxy_page_changed_cb (GtkNotebook *notebook, GtkWidget *page, gint num, EAccount *account)
+proxy_page_changed_cb (GtkNotebook *notebook,
+                       GtkWidget *page,
+                       gint num,
+                       EAccount *account)
 {
 	proxyDialog *prd;
 	proxyDialogPrivate *priv;
@@ -768,7 +777,7 @@ proxy_page_changed_cb (GtkNotebook *notebook, GtkWidget *page, gint num, EAccoun
 
 			list_iter = priv->proxy_list;
 
-			for (;list_iter; list_iter = g_list_next (list_iter)) {
+			for (; list_iter; list_iter = g_list_next (list_iter)) {
 				aclInstance = (proxyHandler *) list_iter->data;
 
 				/* NOTE: All User Access is not supported */
@@ -787,7 +796,8 @@ proxy_page_changed_cb (GtkNotebook *notebook, GtkWidget *page, gint num, EAccoun
 }
 
 static void
-proxy_cancel (GtkWidget *button, EAccount *account)
+proxy_cancel (GtkWidget *button,
+              EAccount *account)
 {
 	proxyDialog *prd = NULL;
 	proxyDialogPrivate *priv;
@@ -799,7 +809,8 @@ proxy_cancel (GtkWidget *button, EAccount *account)
 }
 
 static void
-proxy_add_ok (GtkWidget *button, EAccount *account)
+proxy_add_ok (GtkWidget *button,
+              EAccount *account)
 {
 	proxyDialog *prd = NULL;
 	proxyDialogPrivate *priv;
@@ -816,7 +827,8 @@ proxy_add_ok (GtkWidget *button, EAccount *account)
 }
 
 static void
-proxy_edit_ok (GtkWidget *button, EAccount *account)
+proxy_edit_ok (GtkWidget *button,
+               EAccount *account)
 {
 	proxyDialog *prd = NULL;
 	proxyDialogPrivate *priv;
@@ -833,7 +845,8 @@ proxy_edit_ok (GtkWidget *button, EAccount *account)
 }
 
 static proxyHandler *
-proxy_get_item_from_list (EAccount *account, gchar *account_name)
+proxy_get_item_from_list (EAccount *account,
+                          gchar *account_name)
 {
 	proxyDialogPrivate *priv;
 	proxyDialog *prd = NULL;
@@ -844,7 +857,7 @@ proxy_get_item_from_list (EAccount *account, gchar *account_name)
 	priv = prd->priv;
 	list_iter = priv->proxy_list;
 
-	for (;list_iter; list_iter = g_list_next (list_iter)) {
+	for (; list_iter; list_iter = g_list_next (list_iter)) {
 		iter = (proxyHandler *) list_iter->data;
 
 		if ( g_str_equal (iter->proxy_email,account_name))
@@ -855,13 +868,14 @@ proxy_get_item_from_list (EAccount *account, gchar *account_name)
 }
 
 static void
-proxy_remove_account (GtkWidget *button, EAccount *account)
+proxy_remove_account (GtkWidget *button,
+                      EAccount *account)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	proxyDialogPrivate *priv;
 	proxyHandler *deleted;
-	GtkTreeSelection* account_select;
+	GtkTreeSelection * account_select;
 	gchar *account_mailid;
 	proxyDialog *prd = NULL;
 
@@ -882,18 +896,22 @@ proxy_remove_account (GtkWidget *button, EAccount *account)
 }
 
 static void
-addressbook_dialog_response (ENameSelectorDialog *name_selector_dialog, gint response, gpointer user_data)
+addressbook_dialog_response (ENameSelectorDialog *name_selector_dialog,
+                             gint response,
+                             gpointer user_data)
 {
 	gtk_widget_hide (GTK_WIDGET (name_selector_dialog));
 }
 
 static void
-addressbook_entry_changed (GtkWidget *entry, gpointer user_data)
+addressbook_entry_changed (GtkWidget *entry,
+                           gpointer user_data)
 {
 }
 
 static void
-address_button_clicked (GtkButton *button, EAccount *account)
+address_button_clicked (GtkButton *button,
+                        EAccount *account)
 {
 	proxyDialog *prd;
 	proxyDialogPrivate *priv;
@@ -904,7 +922,8 @@ address_button_clicked (GtkButton *button, EAccount *account)
 }
 
 static void
-proxy_add_account (GtkWidget *button, EAccount *account)
+proxy_add_account (GtkWidget *button,
+                   EAccount *account)
 {
 	GtkButton *contacts, *cancel;
 	proxyDialogPrivate *priv;
@@ -952,7 +971,8 @@ proxy_add_account (GtkWidget *button, EAccount *account)
 }
 
 static void
-proxy_load_edit_dialog (EAccount *account, proxyHandler *edited)
+proxy_load_edit_dialog (EAccount *account,
+                        proxyHandler *edited)
 {
 	proxyDialogPrivate *priv;
 	proxyDialog *prd = NULL;
@@ -1000,12 +1020,13 @@ proxy_load_edit_dialog (EAccount *account, proxyHandler *edited)
 }
 
 static void
-proxy_edit_account (GtkWidget *button, EAccount *account)
+proxy_edit_account (GtkWidget *button,
+                    EAccount *account)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	proxyDialogPrivate *priv;
-	GtkTreeSelection* account_select;
+	GtkTreeSelection * account_select;
 	proxyHandler *edited;
 	GtkButton *okButton, *proxyCancel;
 	gchar *account_mailid;
