@@ -150,7 +150,8 @@ free_node (SharedUser *usr)
 }
 
 static SharedUser *
-find_node (GList *list, gchar *email)
+find_node (GList *list,
+           gchar *email)
 {
 	SharedUser *user = NULL;
 	EShUsers *usr = NULL;
@@ -159,12 +160,12 @@ find_node (GList *list, gchar *email)
 
 	if (list) {
 		tmp = g_list_first (list);
-		for (i=0; tmp; i++)
+		for (i = 0; tmp; i++)
 		{
 			user = tmp->data;
 			usr = user->user_node;
 			if (!g_ascii_strcasecmp (usr->email, email)) {
-				return user; /*if found, it returns that user*/
+				return user; /*if found, it returns that user */
 			}
 			tmp= g_list_next (tmp);
 		}
@@ -299,7 +300,8 @@ get_container_list (ShareFolder *sf)
 }
 
 static void
-shared_clicked (GtkRadioButton *button, ShareFolder *sf)
+shared_clicked (GtkRadioButton *button,
+                ShareFolder *sf)
 {
 
 	gtk_widget_set_sensitive (GTK_WIDGET (sf->table) ,TRUE);
@@ -307,7 +309,8 @@ shared_clicked (GtkRadioButton *button, ShareFolder *sf)
 }
 
 static void
-not_shared_clicked (GtkRadioButton *button, ShareFolder *sf)
+not_shared_clicked (GtkRadioButton *button,
+                    ShareFolder *sf)
 {
 	if (!sf->is_shared) {
 		sf->flag_for_ok = 0;
@@ -319,7 +322,8 @@ not_shared_clicked (GtkRadioButton *button, ShareFolder *sf)
 }
 
 static void
-add_clicked (GtkButton *button, ShareFolder *sf)
+add_clicked (GtkButton *button,
+             ShareFolder *sf)
 {
 	const gchar *email = NULL;
 	const gchar *self_email = NULL;
@@ -380,7 +384,8 @@ add_clicked (GtkButton *button, ShareFolder *sf)
 }
 
 static void
-remove_clicked (GtkButton *button, ShareFolder *sf)
+remove_clicked (GtkButton *button,
+                ShareFolder *sf)
 {
 
 	SharedUser *usr = NULL;
@@ -424,7 +429,7 @@ share_folder (ShareFolder *sf)
 	}
 
 	if (E_IS_GW_CONNECTION (sf->cnc)) {
-		if (sf->flag_for_ok == 2){  /* you have to remove all the users*/
+		if (sf->flag_for_ok == 2){  /* you have to remove all the users */
 		GList *list = NULL;
 
 			if (new_list) {
@@ -476,7 +481,8 @@ share_folder (ShareFolder *sf)
 }
 
 static void
-not_ok_clicked (GtkButton *button, ShareFolder *sf)
+not_ok_clicked (GtkButton *button,
+                ShareFolder *sf)
 {
 
 	gchar *subj = NULL;
@@ -500,13 +506,15 @@ not_ok_clicked (GtkButton *button, ShareFolder *sf)
 }
 
 static void
-not_cancel_clicked (GtkButton *button, GtkWidget *window)
+not_cancel_clicked (GtkButton *button,
+                    GtkWidget *window)
 {
 	gtk_widget_destroy (window);
 }
 
 static void
-notification_clicked (GtkButton *button, ShareFolder *sf)
+notification_clicked (GtkButton *button,
+                      ShareFolder *sf)
 {
 	static  GtkBuilder *builder;
 	GtkButton *not_ok;
@@ -538,19 +546,22 @@ notification_clicked (GtkButton *button, ShareFolder *sf)
 }
 
 static void
-addressbook_entry_changed (GtkWidget *entry, gpointer   user_data)
+addressbook_entry_changed (GtkWidget *entry,
+                           gpointer user_data)
 {
 
 }
 
 static void
-address_button_clicked_cb (GtkButton *button, ShareFolder *sf)
+address_button_clicked_cb (GtkButton *button,
+                           ShareFolder *sf)
 {
 	e_name_selector_show_dialog (sf->name_selector, sf->window);
 }
 
 static void
-user_selected (GtkTreeSelection *selection, ShareFolder *sf)
+user_selected (GtkTreeSelection *selection,
+               ShareFolder *sf)
 {
 	GtkTreeModel *model;
 
@@ -560,7 +571,9 @@ user_selected (GtkTreeSelection *selection, ShareFolder *sf)
 }
 
 static void
-add_right_clicked (GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
+add_right_clicked (GtkCellRenderer *renderer,
+                   gchar *arg1,
+                   ShareFolder *sf)
 {
 	gboolean right = FALSE;
 	SharedUser *usr = NULL;
@@ -579,7 +592,7 @@ add_right_clicked (GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
 		gtk_tree_path_free (path);
 		return;
 	}
-	if (!usr->flag)  /* if user was already existing one change the flag to update*/
+	if (!usr->flag)  /* if user was already existing one change the flag to update */
 		usr->flag = usr->flag | 0x2;
 	user = usr->user_node;
 	if (!right) {
@@ -593,7 +606,9 @@ add_right_clicked (GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
 }
 
 static void
-edit_right_clicked (GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
+edit_right_clicked (GtkCellRenderer *renderer,
+                    gchar *arg1,
+                    ShareFolder *sf)
 {
 	gboolean right = FALSE;
 	SharedUser *usr = NULL;
@@ -612,7 +627,7 @@ edit_right_clicked (GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
 		gtk_tree_path_free (path);
 		return;
 	}
-	if (!usr->flag)  /* if user was already existing one change the flag to update*/
+	if (!usr->flag)  /* if user was already existing one change the flag to update */
 		usr->flag = usr->flag | 0x2;
 	user = usr->user_node;
 
@@ -627,7 +642,9 @@ edit_right_clicked (GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
 }
 
 static void
-delete_right_clicked (GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
+delete_right_clicked (GtkCellRenderer *renderer,
+                      gchar *arg1,
+                      ShareFolder *sf)
 {
 	gboolean right = FALSE;
 	SharedUser *usr = NULL;
@@ -646,7 +663,7 @@ delete_right_clicked (GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
 		gtk_tree_path_free (path);
 		return;
 	}
-	if (!usr->flag)  /* if user was already existing one change the flag to update*/
+	if (!usr->flag)  /* if user was already existing one change the flag to update */
 		usr->flag = usr->flag | 0x2;
 	user = usr->user_node;
 	if (!right) {
@@ -751,7 +768,8 @@ share_folder_construct (ShareFolder *sf)
 }
 
 ShareFolder *
-share_folder_new (EGwConnection *ccnc, gchar *id)
+share_folder_new (EGwConnection *ccnc,
+                  gchar *id)
 {
 	ShareFolder *new;
 	new = (ShareFolder *) g_object_new (share_folder_get_type (), NULL);
